from presidio_analyzer import AnalyzerEngine
from presidio_analyzer.nlp_engine import NlpEngineProvider
from presidio_anonymizer import AnonymizerEngine
from presidio_image_redactor import ImageRedactorEngine
from PIL import Image

class PrivacyDetect:
    def __init__(self):
        nlp_configuration = {
            "nlp_engine_name": "spacy",
            "models": [
                {"lang_code": "en", "model_name": "en_core_web_lg"},
                {"lang_code": "zh", "model_name": "zh_core_web_lg"}
            ]
        }
        provider = NlpEngineProvider(nlp_configuration=nlp_configuration)
        nlp_engine = provider.create_engine()

        self.analyzer = AnalyzerEngine(nlp_engine=nlp_engine, supported_languages=["en", "zh"])
        self.anonymizer = AnonymizerEngine()
        self.image_redactor = ImageRedactorEngine()

    def analyze_text(self, text):
        results = self.analyzer.analyze(text=text, language="zh", entities=[])
        return results

    def anonymize_text(self, text):
        results = self.analyzer.analyze(text=text, language="zh", entities=[])
        anonymized_text = self.anonymizer.anonymize(text, results)
        return anonymized_text
    
    def analyze_image(self, image_path, output_image_path):
        redacted_image = self.image_redactor.redact(Image.open(image_path))
        redacted_image.save(output_image_path)
        return output_image_path
